import React, { useState, useEffect } from "react";
import ReactDOM from "react-dom";
import { BrowserRouter, HashRouter, Route, Switch, Redirect, useHistory } from "react-router-dom";

import "assets/vendor/nucleo/css/nucleo.css";
import "assets/vendor/font-awesome/css/font-awesome.min.css";
import "assets/scss/argon-design-system-react.scss?v1.1.0";

import AddProfile from "./components/Profile/AddProfile";

import Index from "views/Index.js";
import Landing from "views/examples/Landing.js";
import Login from "views/examples/Login.js";
import Profile from "views/examples/Profile.js";
import Register from "views/examples/Register.js";
import NotFound from "views/examples/NotFound.js"
import DetailProfile from "./components/Profile/DetailProfile.js"
import SearchProfile from "./components/Profile/SearchProfile.js";
import Tracecode from "./components/Profile/Tracecode.js"
import AddProduct from "components/Profile/AddProduct";
import Signin from "./services/Signin";
import Signup from "services/Signup";
import { authServices } from "./services/AuthServices";
import { Routes } from "reoutes";
import VerifyCode from "services/VerifyCode";
import ForgotPassword from "services/ForgotPassword";
import ResetPassword from "services/ResetPassword";
import ImageCropper from "components/Generals/ImageCropper/ImageCropper";
// import { Routes } from "./reoutes";

const RouteWithLoader = ({ component: Component, ...rest }) => {
  return (
    <Route {...rest} render={props => authServices.isAuthenticated() ? <Component {...props} /> : <Redirect to={{ pathname: '/login-page' }} />} />
  );
};

export default () => (
  <Switch>
    <Route exact path="/login-page" component={Signin} />
    <Route exact path="/signup" component={Signup} />
    <Route exact path="/verify-code" component={VerifyCode} />
    <Route exact path="/forgot-password" component={ForgotPassword} />
    <Route exact path="/reset-password" component={ResetPassword} />
    <Route exact path="/test" component={ImageCropper} />
    <RouteWithLoader exact path="/" component={SearchProfile} />
    <RouteWithLoader exact path="/profile" component={SearchProfile} />
    <RouteWithLoader exact path="/profile/add" component={AddProfile} />
    <RouteWithLoader exact path="/profile/add-product" component={AddProduct} />
    <RouteWithLoader exact path="/profile/:code" component={DetailProfile} />
    <RouteWithLoader exact path="/trace-code/:trace" component={Tracecode} />
    <RouteWithLoader exact path="/not-found" component={NotFound} />
  </Switch>
);
