import React, { useState, useCallback } from 'react';
import { Input, Button, Modal, ModalHeader, ModalBody, ModalFooter, Row, Container } from 'reactstrap';
import Cropper from 'react-easy-crop';
import { Range, getTrackBackground } from 'react-range';
import getCroppedImg from './CropImage'

import './ImageCropper.scss'
const ImageCropper = (props) => {
  const { onSaveImage } = props;
  const MAX_ZOOM = 4
  const MIN_ZOOM = 1

  const [crop, setCrop] = useState({ x: 0, y: 0 })
  const [zoom, setZoom] = useState([1])
  const [rotation, setRotation] = useState(0);
  const [image, setImage] = useState(null);
  const [croppedAreaPixels, setCroppedAreaPixels] = useState(null)
  const [croppedImage, setCroppedImage] = useState(null)

  const [modal, setModal] = useState(false);

  const toggle = () => setModal(!modal);

  const handleFileChoose = (event) => {
    if (URL.createObjectURL(event.target.files[0])) {
      setImage(URL.createObjectURL(event.target.files[0]));
      toggle();
    }
  }

  const onCropComplete = useCallback((croppedArea, croppedAreaPixels) => {
    setCroppedAreaPixels(croppedAreaPixels);
  }, [])

  const handleCrop = () => {
    showCroppedImage()
  }

  const showCroppedImage = useCallback(async () => {
    try {
      const croppedImage = await getCroppedImg(
        image,
        croppedAreaPixels,
        rotation
      )
      console.log('donee', { croppedImage })
      onSaveImage(croppedImage)
      setCroppedImage(croppedImage)
      toggle();
    } catch (e) {
      console.error(e)
    }
  }, [croppedAreaPixels, rotation])

  return (
    <>
      <Input type="file" name="file" id="file-logo" className="w-auto" onChange={handleFileChoose}
        onClick={(event) => {
          event.target.value = null
        }} />
      <Modal isOpen={modal} toggle={toggle} className="modal-lg" contentClassName="modal-image-cropper">
        <ModalHeader toggle={toggle}>Chọn phần ảnh mong muốn</ModalHeader>
        <ModalBody>
          <Cropper
            image={image}
            crop={crop}
            zoom={zoom}
            aspect={1 / 1}
            onCropChange={setCrop}
            onCropComplete={onCropComplete}
            onZoomChange={setZoom}
          />
        </ModalBody>
        <Container>
          <Row className="px-5 my-4">
            <Range
              step={0.05}
              min={MIN_ZOOM}
              max={MAX_ZOOM}
              values={zoom}
              onChange={(values) => setZoom(values)}
              renderTrack={({ props, children }) => (
                <div
                  {...props}
                  style={{
                    ...props.style,
                    height: "5px",
                    width: "100%",
                    borderRadius: "4px",
                    background: getTrackBackground({
                      values: zoom,
                      colors: ["#5e73e5", "#ccc"],
                      min: MIN_ZOOM,
                      max: MAX_ZOOM
                    }),
                    alignSelf: "center",
                  }}
                >
                  {children}
                </div>
              )}
              renderThumb={({ props }) => (
                <div
                  {...props}
                  style={{
                    ...props.style,
                    height: "42px",
                    width: "42px",
                    borderRadius: "4px",
                    backgroundColor: "#FFF",
                    display: "flex",
                    justifyContent: "center",
                    alignItems: "center",
                    boxShadow: "0px 2px 6px #AAA"
                  }}
                >
                  <div
                    style={{
                      height: "16px",
                      width: "5px",
                      backgroundColor: "#5e73e5"
                    }}
                  />
                </div>
              )}
            />
          </Row>
        </Container>
        <ModalFooter>
          <Button color="secondary" onClick={toggle}>Quay lại</Button>
          <Button color="primary" onClick={handleCrop}>Xác nhận</Button>{' '}
        </ModalFooter>
      </Modal>
    </>

  )
}

export default ImageCropper;