import React, { useState } from "react";
import { useHistory } from "react-router";
import { v4 as uuidv4 } from 'uuid';
import { Container, Form, FormGroup, Label, InputGroup, InputGroupAddon, InputGroupText, Input, Button, Row, Col, FormText } from "reactstrap";

// core components
import MainBanner from "../Generals/MainBanner.js";
import DemoNavbar from "../Navbars/DemoNavbar.js";
import dummyData from "../../data/index.json";
import { ProductDiaryTable } from "../../views/IndexSections/Table.js";
import ImageCropper from "components/Generals/ImageCropper/ImageCropper.js";

const AddProduct = () => {
  const history = useHistory();
  const state = { ...history.location.state };
  const profileId = state.profileId;
  const productId = state.productId;
  const detailProduct = productId ? state.detailProduct[0] : {};

  const [productName, setProductName] = useState(productId ? detailProduct.name : "");
  const [traceCode, setTraceCode] = useState(productId ? detailProduct.trace_code : "");
  const [cost, setCost] = useState(productId ? detailProduct.cost : "");
  const [origin, setOrigin] = useState(productId ? detailProduct.origin : "");
  const [productImage, setProductImage] = useState(productId ? detailProduct.image : "");
  const [description, setDescription] = useState(productId ? detailProduct.description : "");
  const [growingConditions, setGrowingConditions] = useState(productId ? detailProduct.growing_conditions : "");

  const onHandleBack = () => {
    history.push("/profile/add");
  }

  const onHandleAddProduct = (event) => {
    event.preventDefault();
    const getTime = new Date().getTime();
    const params = {
      product_id: uuidv4(),
      trace_code: traceCode,
      name: productName,
      image: "",
      cost,
      origin,
      description,
      growing_conditions: growingConditions,
      created_at: getTime,
      qr_code: ""
    }
    if (profileId) {
      const newData = dummyData.data.filter(item => item.id === profileId);
      newData.profile_product.push(params);
    }
    history.push("/profile/add");
  }


  return (
    <>
      <DemoNavbar />
      <main>
        <MainBanner />
        <section className="section section-components">
          <Container>
            <Form onSubmit={onHandleAddProduct}>
              <h5 className="mb-3">{productId ? "Sửa thông tin sản phẩm" : "Thêm mới sản phẩm"}</h5>
              <FormGroup>
                <Label for="product-name">Tên sản phẩm</Label>
                <InputGroup className="mb-4">
                  <InputGroupAddon addonType="prepend">
                    <InputGroupText>
                      <i className="fa fa-product-hunt" />
                    </InputGroupText>
                  </InputGroupAddon>
                  <Input
                    placeholder="Tên sản phẩm"
                    type="text"
                    className="text-dark"
                    value={productName}
                    onChange={(e) => setProductName(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup>
                <Label for="product-name">Mã sản phẩm</Label>
                <InputGroup className="mb-4">
                  <InputGroupAddon addonType="prepend">
                    <InputGroupText>
                      <i className="fa fa-codepen" />
                    </InputGroupText>
                  </InputGroupAddon>
                  <Input
                    placeholder="Mã sản phẩm"
                    type="text"
                    className="text-dark"
                    value={traceCode}
                    onChange={(e) => setTraceCode(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup>
                <Label for="product-name">Giá sản phẩm</Label>
                <InputGroup className="mb-4">
                  <InputGroupAddon addonType="prepend">
                    <InputGroupText>
                      <i className="fa fa-usd" />
                    </InputGroupText>
                  </InputGroupAddon>
                  <Input
                    placeholder="Giá sản phẩm"
                    type="text"
                    className="text-dark"
                    value={cost}
                    onChange={(e) => setCost(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup>
                <Label for="product-name">Xuất xứ</Label>
                <InputGroup className="mb-4">
                  <InputGroupAddon addonType="prepend">
                    <InputGroupText>
                      <i className="fa fa-wrench" />
                    </InputGroupText>
                  </InputGroupAddon>
                  <Input
                    placeholder="Xuất xứ"
                    type="text"
                    className="text-dark"
                    value={origin}
                    onChange={(e) => setOrigin(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup>
                <Label for="product-name">Mô tả</Label>
                <InputGroup className="mb-4">
                  <Input
                    placeholder="Mô tả"
                    type="textarea"
                    className="text-dark"
                    value={description}
                    onChange={(e) => setDescription(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup>
                <Label for="product-name">Điều kiện nuôi trồng</Label>
                <InputGroup className="mb-4">
                  <Input
                    placeholder="Điều kiện nuôi trồng"
                    type="textarea"
                    className="text-dark"
                    value={growingConditions}
                    onChange={(e) => setGrowingConditions(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup row>
                <Col sm={10}>
                  <ImageCropper onSaveImage={setProductImage} />
                  <FormText color="muted">
                    Lựa chọn ảnh sản phẩm
                  </FormText>
                </Col>
              </FormGroup>
              <div className="mt-3">
                <ProductDiaryTable listProductDiary={detailProduct.product_chain_diary} />
              </div>
              <div className="d-flex justify-content-between mt-3">
                <Button
                  color="secondary"
                  type="button"
                  className="btn-1"
                  onClick={onHandleBack}
                >
                  Quay lại
                </Button>
                <Button
                  color="primary"
                  type="submit"
                  className="btn-1"
                >
                  {productId ? "Sửa" : "Thêm mới"}
                </Button>
              </div>
            </Form>
          </Container>
        </section>
      </main>
    </>
  );
}

export default AddProduct;