import React, { useState } from "react";
import { useHistory } from "react-router";
import { v4 as uuidv4 } from 'uuid';
import { Container, Form, FormGroup, Label, InputGroup, InputGroupAddon, InputGroupText, Input, Button, Col, FormText, FormFeedback } from "reactstrap";

// core components
import MainBanner from "../Generals/MainBanner.js";
import DemoNavbar from "../Navbars/DemoNavbar.js";
import dummyData from "../../data/index.json";

import { validatePhoneNumber } from "constans/index.js";
import { ProductTable } from "../../views/IndexSections/Table.js";
import ImageCropper from "components/Generals/ImageCropper/ImageCropper.js";

const AddProfile = () => {
  const history = useHistory();
  const state = { ...history.location.state };
  const profileId = state.profileId;
  const detailProfile = profileId ? state.detailProfile[0] : "";

  const [profileName, setProfileName] = useState(profileId ? detailProfile.name : "");
  const [profileCode, setProfileCode] = useState(profileId ? detailProfile.code : "");
  const [logo, setLogo] = useState(profileId ? detailProfile.logo : "");
  const [phoneNumber, setPhoneNumber] = useState(profileId ? detailProfile.phone_number : "");
  const [profileAddress, setProfileAddress] = useState(profileId ? detailProfile.address : "");
  const [validPhoneNumber, setValidPhoneNumber] = useState(false);

  const onHandleBack = () => {
    history.push("/");
  }

  const toBase64 = file => new Promise((resolve, reject) => {
    const reader = new FileReader();
    reader.readAsDataURL(file);
    reader.onload = () => resolve(reader.result);
    reader.onerror = error => reject(error);
  });

  const onHandleAddNewProfile = async (event) => {
    event.preventDefault();
    if (validatePhoneNumber(phoneNumber)) {
      const getTime = new Date().getTime();
      const params = {
        id: uuidv4(),
        code: profileCode,
        name: profileName,
        logo: "",
        phone_number: phoneNumber,
        address: profileAddress,
        created_at: getTime,
        qr_code: ""
      }
      dummyData.data.push(params);
      history.push("/profile");
      setValidPhoneNumber(false);
    } else {
      setValidPhoneNumber(true);
    }
  }

  return (
    <>
      <DemoNavbar />
      <main>
        <MainBanner />
        <section className="section section-components">
          <Container>
            <Form onSubmit={onHandleAddNewProfile}>
              <h5 className="mb-3">{profileId ? "Sửa thông tin doanh nghiệp" : "Thêm mới doanh nghiệp"}</h5>
              <FormGroup className="mb-4">
                <Label for="profile_name" >Tên doanh nghiệp</Label>
                <InputGroup className="mb-4">
                  <InputGroupAddon addonType="prepend">
                    <InputGroupText>
                      <i className="fa fa-building" />
                    </InputGroupText>
                  </InputGroupAddon>
                  <Input
                    required
                    placeholder="Tên doanh nghiệp"
                    type="text"
                    className="text-dark"
                    value={profileName}
                    onChange={(e) => setProfileName(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup className="mb-4">
                <Label for="profile_name" >Mã code</Label>
                <InputGroup className="mb-4">
                  <InputGroupAddon addonType="prepend">
                    <InputGroupText>
                      <i className="fa fa-codepen" />
                    </InputGroupText>
                  </InputGroupAddon>
                  <Input
                    required
                    placeholder="Mã code"
                    type="text"
                    className="text-dark"
                    value={profileCode}
                    onChange={(e) => setProfileCode(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup className="mb-4">
                <Label for="phone_number" >Số điện thoại</Label>
                <InputGroup className="mb-4">
                  <InputGroupAddon addonType="prepend">
                    <InputGroupText>
                      <i className="fa fa-phone" />
                    </InputGroupText>
                  </InputGroupAddon>
                  <Input
                    placeholder="Số điện thoại"
                    type={phoneNumber ? "text" : "number"}
                    className="text-dark"
                    value={phoneNumber}
                    onChange={(e) => setPhoneNumber(e.target.value)}
                    invalid={validPhoneNumber}
                  />
                  <FormFeedback invalid>{validPhoneNumber ? "Phải có 10 chữ số bắt đầu bằng chữ số 0" : ""}</FormFeedback>
                </InputGroup>
              </FormGroup>
              <FormGroup className="mb-4">
                <Label for="address" >Địa chỉ</Label>
                <InputGroup className="mb-4">
                  <Input
                    placeholder="Địa chỉ"
                    type="textarea"
                    className="text-dark"
                    value={profileAddress}
                    onChange={(e) => setProfileAddress(e.target.value)}
                  />
                </InputGroup>
              </FormGroup>
              <FormGroup row>
                <Col sm={10}>
                  <ImageCropper onSaveImage={setLogo}/>
                  <FormText color="muted">
                    Lựa chọn logo công ty
                  </FormText>
                </Col>
              </FormGroup>
              <div className="mt-3">
                <ProductTable listProduct={detailProfile.profile_product} />
              </div>
              <div className="d-flex justify-content-between mt-3">
                <Button
                  color="secondary"
                  type="button"
                  className="btn-1"
                  onClick={onHandleBack}
                >
                  Quay lại
                </Button>
                <Button
                  color="primary"
                  type="submit"
                  className="btn-1"
                >
                  {profileId ? "Sửa" : "Thêm mới"}
                </Button>
              </div>
            </Form>
          </Container>

        </section>
      </main>
    </>
  );
}

export default AddProfile;