import React, { useState } from "react";
import { connect, useDispatch } from "react-redux";
import { useHistory } from 'react-router-dom';

import { Card, Container, Row, Col, CardHeader, CardBody, CardText, CardFooter, CardTitle } from "reactstrap";
import QRCode from 'qrcode.react';


// core components
import MainBanner from "components/Generals/MainBanner.js";
import Sologan from "components/Generals/Sologan";
import DemoNavbar from "components/Navbars/DemoNavbar.js";
import SimpleFooter from "components/Footers/SimpleFooter.js";

import dummyData from "../../data/index.json";

import './detail-profile.css';

const DetailProfile = (props) => {
  const history = useHistory();
  const state = { ...history.location.state };
  const code_name = state.code_name;
  const listData = dummyData.data.filter(item => item.code === code_name);

  return (
    <>
      <DemoNavbar />
      <main>
        <MainBanner />
        <section className="section bg-secondary">
          {listData && listData.length > 0 ?
            listData.map(data => {
              return (
                <Container key={data.id}>
                  <Row className="row-grid align-items-center">
                    <Col md={6} >
                      <div className="d-flex justify-content-center">
                        <QRCode
                          size={250}
                          // fgColor="#7f0000"
                          includeMargin
                          value={`http://trace.aqbits.net/trace-code/${data.qr_code}`}
                          imageSettings={{
                            width: 120,
                            height: 60, 
                            src: window.location.origin + data.logo, 
                            excavate: true,
                          }}
                        />
                      </div>
                    </Col>
                    <Col md={6}>
                      <div className="h2 mb-3">{data.name}</div>
                      <div className="mb-3">
                        <div className="h5 font-weight-bold">Số điện thoại</div>
                        <div className="h5">{data.phone_number}</div>
                      </div>
                      <div className="mb-3">
                        <div className="h5 font-weight-bold">Địa chỉ</div>
                        <div className="h5">{data.address}</div>
                      </div>
                    </Col>
                  </Row>
                  <Row>
                    <Col md={12}>
                      <div className="h5 font-weight-bold mt-5">Danh sách sản phẩm</div>
                    </Col>
                  </Row>
                  <Row className="row-grid">
                    {data.profile_product && data.profile_product.length > 0 ? data.profile_product.map(product => {
                      const onHandleTraceCode = () => {
                        history.push({
                          pathname: `/trace-code/${product.trace_code}`,
                          state: { product }
                        });
                      }
                      return (
                        <Col lg={6} md={12} className="my-3" key={product.product_id}>
                          <Card className="w-100 h-100 hover-shadow" onClick={onHandleTraceCode}>
                            <CardHeader className="h5 mb-3">{product.name}</CardHeader>
                            <CardBody>
                              <div className="d-flex justify-content-around">
                                <QRCode
                                  size={250}
                                  includeMargin
                                  value={`http://trace.aqbits.net/trace-code/${product.trace_code}`}
                                  imageSettings={{
                                    width: 120,
                                    height: 80,
                                    src: window.location.origin + product.image,
                                    excavate: true,
                                  }}
                                />
                              </div>
                              <h5>Mô tả</h5>
                              <CardText>{product.description}</CardText>
                            </CardBody>
                          </Card>
                        </Col>
                      );
                    }) : null}
                  </Row>
                </Container>
              );
            }) : <div className="h4 font-weight-bold">Not found profile</div>
          }
        </section>
        <Sologan />
      </main>
      <SimpleFooter />
    </>
  );
}

const mapStateToProps = (state) => {
  return {
    listProfile: state.profileReducer.listProfile,
    // currentPage: state.profileReducer.currentPage,
    // limit: state.profileReducer.limit,
    // nextPage: state.profileReducer.nextPage,
    // previosPage: state.profileReducer.previosPage,
    // total: state.profileReducer.total
  };
};
const mapDispatchToProps = (dispatch) => ({
  // onLoadListProfile: (profile) => dispatch(listProfile(profile)),
  // onLoadPreviousPage: (profile) => dispatch(previousAction(profile)),
  // onLoadNextPage: (profile) => dispatch(nextAction(profile)),
  // onDeleteProfile: (profile) => dispatch(deleteProfile(profile)),
  // onAddProfile: (profile) => dispatch(addProfile(profile))
});

export default connect(mapStateToProps, mapDispatchToProps)(DetailProfile);


