/* eslint-disable react-hooks/exhaustive-deps */
import React, { useState, useEffect } from "react";
import { connect, useDispatch } from "react-redux";
import { useHistory } from 'react-router-dom';
import { FormGroup, Input, InputGroupAddon, InputGroupText, InputGroup, Container, Button, Form } from "reactstrap";

// core components
import DemoNavbar from "components/Navbars/DemoNavbar.js";
import MainBanner from "components/Generals/MainBanner.js";
import Sologan from "components/Generals/Sologan.js";
import SimpleFooter from "components/Footers/SimpleFooter";

import { listProfile, addProfile, deleteProfile, previousAction, nextAction } from "../../store/actions/ProfileAction";
import { ProfileTable } from "../../views/IndexSections/Table";

import dummyData from "../../data/index.json";


const SearchProfile = (props) => {
  const [searchProfile, setSearchProfile] = useState("");
  const history = useHistory();
  const dispatch = useDispatch();

  const handleChangeSearch = (event) => {
    setSearchProfile(event.target.value);
  }

  const onHandleSearch = (event) => {
    event.preventDefault();
    if (!searchProfile) return;
    const nameCode = dummyData.data.map(item => item.code);
    const checkSearch = nameCode.indexOf(searchProfile);
    if (checkSearch !== -1) {
      history.push({
        pathname: `/profile/${searchProfile}`,
        state: { code_name: searchProfile }
      });
    } else {
      history.push("/not-found");
    }
  }

  // useEffect(() => {
  //   dispatch(props.onLoadListProfile( { currentPage: props.currentPage, limit: props.limit } ));
  // }, []);



  return (
    <>
      <DemoNavbar />
      <main>
        <MainBanner />
        <section className="section pb-0 section-components">
          <Container className="mb-5">
            <h3 className="h4 text-primary mb-4 font-weight-bold text-center">Tra cứu thông tin doanh nghiệp</h3>
            <Form className="justify-content-center" onSubmit={onHandleSearch}>
              <FormGroup>
                <InputGroup className="mb-4">
                  <InputGroupAddon addonType="prepend">
                    <InputGroupText>
                      <i className="fa fa-search"></i>
                    </InputGroupText>
                  </InputGroupAddon>
                  <Input
                    placeholder="Tìm kiếm"
                    type="text"
                    value={searchProfile}
                    onChange={handleChangeSearch}
                  />
                </InputGroup>
              </FormGroup>
              <div className="text-center">
                <Button className="btn-1" color="primary" type="submit">
                  Tìm kiếm
                </Button>
              </div>
            </Form>
          </Container>
        </section>
        <section className="section">
          <ProfileTable 
            listProfile={dummyData.data}
            currentPage={props.currentPage} 
            limit={props.limit} 
            nextPage={props.nextPage} 
            previosPage={props.previosPage}
            total={dummyData.data.length}
            onLoadListProfile={props.onLoadListProfile}
            onLoadPreviousPage={props.onLoadPreviousPage}
            onLoadNextPage={props.onLoadNextPage}
          />
        </section>
        <Sologan />
      </main>
      <SimpleFooter />
    </>
  );
}

const mapStateToProps = (state) => {
  return {
    listProfile: state.profileReducer.listProfile,
    currentPage: state.profileReducer.currentPage,
    limit: state.profileReducer.limit,
    nextPage: state.profileReducer.nextPage,
    previosPage: state.profileReducer.previosPage,
    total: state.profileReducer.total
  };
};
const mapDispatchToProps = (dispatch) => ({
  onLoadListProfile: (profile) => dispatch(listProfile(profile)),
  onLoadPreviousPage: (profile) => dispatch(previousAction(profile)),
  onLoadNextPage: (profile) => dispatch(nextAction(profile)),
  // onDeleteProfile: (profile) => dispatch(deleteProfile(profile)),
  // onAddProfile: (profile) => dispatch(addProfile(profile))
});

export default connect(mapStateToProps, mapDispatchToProps)(SearchProfile);
