import React, { useState } from "react";
import { useHistory } from 'react-router-dom';

// nodejs library that concatenates classes
import classnames from "classnames";

// reactstrap components
import { Card, CardBody, CardImg, Container, NavItem, NavLink, Nav, TabContent, TabPane, Row, Col } from "reactstrap";

// core components
import MainBanner from "components/Generals/MainBanner.js";
import DemoNavbar from "components/Navbars/DemoNavbar.js";
import SimpleFooter from "components/Footers/SimpleFooter.js";
import { formatDateTime } from '../../constans/index.js';


const Tracecode = () => {
  const [plainTabs, setPlainTabs] = useState(1);
  const history = useHistory();
  let state = { ...history.location.state };
  const product = state.product;

  const toggleNavs = (e, index) => {
    e.preventDefault();
    setPlainTabs(index);
  };

  const renderProductInfo = (product) => {
    return (
      <>
        <section className="section bg-secondary">
          <Container>
            <Row className="row-grid align-items-center">
              <Col md="6">
                <Card className="bg-default shadow border-0">
                  <CardImg
                    alt="..."
                    src={window.location.origin + product.image}
                    top
                  />
                </Card>
              </Col>
              <Col md="6">
                <div className="pl-md-5">
                  <div className="h3 font-weight-bold m3">{product.name}</div>
                  <div className="h5 mb-3">Mã sản phẩm <span className="font-weight-bold">{product.trace_code}</span></div>
                  <div className="h5 mb-3">Xuất xứ <span className="font-weight-bold">{product.origin}</span></div>
                  <div className="h5 mb-3" style={{ color: '#33CC66' }}>Giá: {product.cost}</div>
                </div>
              </Col>
            </Row>
          </Container>
        </section>
      </>
    );
  }
  const renderTabs = (product) => {
    return (
      <>
        <Row className="justify-content-center">
          <Col className="mt-5 mt-lg-0" lg="10">
            {/* Menu */}
            <div className="nav-wrapper">
              <Nav
                className="nav-fill flex-column flex-md-row"
                id="tabs-icons-text"
                pills
                role="tablist"
              >
                <NavItem>
                  <NavLink
                    aria-selected={plainTabs === 1}
                    className={classnames("mb-sm-3 mb-md-0", {
                      active: plainTabs === 1
                    })}
                    onClick={e => toggleNavs(e, 1)}
                    href="#pablo"
                    role="tab"
                  >
                    Thông tin chung
                  </NavLink>
                </NavItem>
                <NavItem>
                  <NavLink
                    aria-selected={plainTabs === 2}
                    className={classnames("mb-sm-3 mb-md-0", {
                      active: plainTabs === 2
                    })}
                    onClick={e => toggleNavs(e, 2)}
                    href="#pablo"
                    role="tab"
                  >
                    Nhật kí chuỗi
                  </NavLink>
                </NavItem>
                <NavItem>
                  <NavLink
                    aria-selected={plainTabs === 3}
                    className={classnames("mb-sm-3 mb-md-0", {
                      active: plainTabs === 3
                    })}
                    onClick={e => toggleNavs(e, 3)}
                    href="#pablo"
                    role="tab"
                  >
                    Chứng nhận
                  </NavLink>
                </NavItem>
              </Nav>
            </div>
            <Card className="shadow">
              <CardBody>
                <TabContent activeTab={"plainTabs" + plainTabs}>
                  <TabPane tabId="plainTabs1">
                    <div className="description">
                      <div className="h3 font-weight-bold mb-3">{product.name}</div>
                      <div className="h5 mb-3">Mã sản phẩm <span className="font-weight-bold">{product.trace_code}</span></div>
                      <div className="h5 mb-3">Xuất xứ <span className="font-weight-bold">{product.origin}</span></div>
                      <div className="h5 mb-3" style={{ color: '#33CC66' }}>Giá: {product.cost}</div>
                    </div>
                  </TabPane>
                  <TabPane tabId="plainTabs2">
                    <div className="description">
                      {product.product_chain_diary.map(diary => (
                        <div key={diary.id}>
                          <div className="h5 font-weight-bold mt-3">{diary.company}</div>
                          <Row className="h6 mb-3">
                            <Col xs={4}>{formatDateTime(diary.date)}</Col>
                            <Col xs={6}>{diary.description}</Col>
                            <Col></Col>
                          </Row>
                        </div>
                      ))}
                    </div>
                  </TabPane>
                  <TabPane tabId="plainTabs3">
                    <div className="description">
                      <Row>
                        {product.product_certification.map((certificate) => (
                          <Col xs={4} key={certificate.id}>
                            <img src={window.location.origin + certificate.image} alt="certificate" height="250px" />
                            <div className="h5 mt-3 mb-3 font-weight-bold">{certificate.certification_information}</div>
                          </Col>
                        ))}
                      </Row>
                    </div>
                  </TabPane>
                </TabContent>
              </CardBody>
            </Card>
          </Col>
        </Row>
      </>
    );
  }

  return (
    <>
      <DemoNavbar />
      <main>
        <MainBanner />
        {renderProductInfo(product)}
        <section className="section bg-gradient-warning">
          <Container>
            {renderTabs(product)}
          </Container>
        </section>
      </main>
      <SimpleFooter />
    </>
  );

}

export default Tracecode;
