import {
  CognitoUser,
  CognitoUserPool,
  CognitoUserAttribute,
  AuthenticationDetails,
} from "amazon-cognito-identity-js";

const poolData = {
  UserPoolId: process.env.REACT_APP_AWS_USER_POOL_ID,
  ClientId: process.env.REACT_APP_AWS_CLIENT_ID,
};

const userPool = new CognitoUserPool(poolData);

export const authServices = {
  signUp: (email, password) => {
    return new Promise((resolve, reject) => {
      const userName = email.split("@")[0];
      const attributeList = [];
      const dataEmail = {
        Name: "email",
        Value: email,
      };
      const dataPhoneNumber = {
        Name: "phone_number",
        Value: "+0358853172",
      };

      const dataName = {
        Name: "name",
        Value: userName,
      };

      const dataRole = {
        Name: "custom:role",
        Value: "ADMIN",
      };
      const attributeEmail = new CognitoUserAttribute(dataEmail);
      const attributePhoneNumber = new CognitoUserAttribute(dataPhoneNumber);
      const atrributeName = new CognitoUserAttribute(dataName);
      const atrributeRole = new CognitoUserAttribute(dataRole);
      attributeList.push(attributeEmail);
      attributeList.push(attributePhoneNumber);
      attributeList.push(atrributeName);
      attributeList.push(atrributeRole);

      userPool.signUp(
        userName,
        password,
        attributeList,
        null,
        function (err, result) {
          if (err) {
            return reject(err);
          }
          var cognitoUser = result.user;
          localStorage.setItem("signup_user_name", cognitoUser.getUsername());
          return resolve(cognitoUser.getUsername());
        }
      );
    });
  },
  verifyCode: (verifyCode) => {
    return new Promise((resolve, reject) => {
      const signUpUserName = localStorage.getItem("signup_user_name");
      var userData = {
        Username: signUpUserName,
        Pool: userPool,
      };
      var cognitoUser = new CognitoUser(userData);
      cognitoUser.confirmRegistration(verifyCode, true, function (err, result) {
        if (err) {
          return reject(err);
        }
        return resolve(result);
      });
    });
  },
  login: (email, password) => {
    return new Promise((resolve, reject) => {
      const userName = email.split("@")[0];
      var authenticationData = {
        email,
        Password: password,
      };
      var authenticationDetails = new AuthenticationDetails(authenticationData);
      var userData = {
        Username: userName,
        Pool: userPool,
      };
      var cognitoUser = new CognitoUser(userData);
      cognitoUser.authenticateUser(authenticationDetails, {
        onSuccess: function (result) {
          var accessToken = result.getAccessToken().getJwtToken();
          localStorage.setItem("access_token", accessToken);
          var idToken = result.getIdToken().getJwtToken();
          localStorage.setItem("id_token", idToken);
          localStorage.setItem("signin_user_name", userName);
          resolve(result);
        },
        onFailure: function (err) {
          reject(err);
        },
      });
    });
  },
  forgotPassword: (email) => {
    return new Promise((resolve, reject) => {
      var userData = {
        Username: email,
        Pool: userPool,
      };
      var cognitoUser = new CognitoUser(userData);
      cognitoUser.forgotPassword({
        onSuccess: function(data) {
          localStorage.setItem("forgot_password", email);
          resolve(data);
        },
        onFailure: function(err) {
          reject(err);
        }
      });
    });
  },
  resetPassword: (code, newPassword) => {
    return new Promise((resolve, reject) => {
      const email = localStorage.getItem("forgot_password"); 
      var userData = {
        Username: email,
        Pool: userPool,
      };
      var cognitoUser = new CognitoUser(userData);
      cognitoUser.confirmPassword(code, newPassword, {
        onSuccess() {
          resolve(code, newPassword);
        },
        onFailure(err) {
          reject(err);
        },
      });
    });
  },
  isAuthenticated: () => {
    return localStorage.getItem("access_token") && localStorage.getItem("id_token");
  },
  logout: () => {
    localStorage.removeItem("access_token");
    localStorage.removeItem("id_token");
  },
  checkUserRole: () => {
    const cognitoUser = userPool.getCurrentUser();
    const session = cognitoUser.getSession((err, session) => {
      return session.idToken.payload['custom:role'];
    });
    return session;
  }
};
