import React, { useState } from "react";
import {
  Alert,
  Button,
  Card,
  CardBody,
  FormGroup,
  Form,
  FormFeedback,
  Input,
  InputGroupAddon,
  InputGroupText,
  InputGroup,
  Container,
  Row,
  Col,
  Spinner,
  CardHeader
} from "reactstrap";
import { Link, useHistory } from "react-router-dom";

// core components
import DemoNavbar from "components/Navbars/DemoNavbar.js";
import SimpleFooter from "components/Footers/SimpleFooter.js";

import { Routes } from "../reoutes";
import { authServices } from "./AuthServices";
import { validateEmail } from "constans";

export default () => {
  const [loading, setLoading] = useState(false);
  const [email, setEmail] = useState("");
  const [validEmail, setValidEmail] = useState(false);
  const [showMessage, setShowMessage] = useState(false);
  const [errorMessage, setErrorMessage] = useState("");

  const history = useHistory();

  const onHandleForgotPassword = () => {
    if (validateEmail(email)) {
      setLoading(true);
      setShowMessage(false);
      setValidEmail(false);
      authServices
        .forgotPassword(email)
        .then((rs) => {
          history.push(Routes.ResetPassword.path);
          setShowMessage(false);
          setLoading(false);
        })
        .catch((err) => {
          setShowMessage(true);
          setLoading(false);
          setErrorMessage(err.message);
        });
    } else {
      setShowMessage(false);
      setValidEmail(true);
    }
  }

  return (
    <>
      <DemoNavbar />
      <main>
        <section className="section section-shaped section-full">
          <div className="shape shape-style-1 bg-gradient-default">
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
          </div>
          <Container className="pt-lg-7">
            {showMessage ? (
              <div className="text-center"><Alert className="px-lg-5" color="danger">{errorMessage}</Alert></div>
            ) : (
              false
            )}
            {loading ? (
              <div className="text-center mb-3">
                <Spinner color="primary" />
              </div>
            ) : (
              false
            )}
            <Row className="justify-content-center">
              <Col lg={5}>
                <Card className="bg-secondary shadow border-0">
                  <CardHeader>
                    <h5 className="text-center text-primary">Khôi phục mật khẩu</h5>
                  </CardHeader>
                  <CardBody className="px-lg-5 py-lg-5">
                    <Form role="form" onSubmit={onHandleForgotPassword}>

                      <FormGroup id="code">
                        <InputGroup className="input-group-alternative mb-3">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-email-83" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            required
                            autoFocus
                            type="text"
                            placeholder="Email của bạn"
                            value={email}
                            onChange={(e) => setEmail(e.target.value)}
                            invalid={validEmail} />
                          <FormFeedback className="bg-transparent shadow-0">{validEmail === true ? "Không đúng định dạng email" : ""}</FormFeedback>
                        </InputGroup>
                      </FormGroup>
                      <div className="text-center">
                        <Button
                          className="mt-4"
                          color="primary"
                          type="submit"
                        >
                          Xác nhận
                        </Button>
                      </div>
                    </Form>
                  </CardBody>
                </Card>
                <Row className="mt-3">
                  <Col className="d-flex justify-content-start align-items-center">
                    <small className="text-light mr-2">
                      Không đổi mật khẩu?
                    </small>
                    <Link
                      to={Routes.Signin.path}>
                      <small className="text-primary">
                        Đăng nhập
                      </small>
                    </Link>
                  </Col>
                </Row>
              </Col>
            </Row>
          </Container>
        </section>
      </main>
      {/* <SimpleFooter /> */}
    </>
  );
};
