
import React, { useState } from "react";
import { Link, useHistory } from 'react-router-dom';

import { Routes } from "../reoutes";
import { authServices } from "./AuthServices";

import {
  Alert,
  Button,
  Card,
  CardBody,
  FormGroup,
  Form,
  FormFeedback,
  Input,
  InputGroupAddon,
  InputGroupText,
  InputGroup,
  Container,
  Row,
  Col,
  Spinner,
  CardHeader
} from "reactstrap";

// core components
import DemoNavbar from "components/Navbars/DemoNavbar.js";
import SimpleFooter from "components/Footers/SimpleFooter.js";

export default () => {
  const [loading, setLoading] = useState(false);
  const [code, setCode] = useState("");
  const [newPassword, setNewPassword] = useState("");
  const [confirmPassword, setConfirmPassword] = useState("");

  const [checkPassword, setCheckPassword] = useState(false);
  const [showMessage, setShowMessage] = useState(false);
  const [errorMessage, setErrorMessage] = useState("");

  const history = useHistory();

  const onHandleResetPassword = (event) => {
    event.preventDefault();
    if (newPassword === confirmPassword) {
      setLoading(true);
      setShowMessage(false);
      setCheckPassword(false);
      authServices
        .resetPassword(code, newPassword)
        .then((rs) => {
          history.push(Routes.Signin.path);
          setShowMessage(false);
          setLoading(false);
        })
        .catch((err) => {
          setShowMessage(true);
          setLoading(false);
          setErrorMessage(err.message);
        });
    } else {
      setShowMessage(false);
      setCheckPassword(true);
    }
  };

  return (
    <>
      <DemoNavbar />
      <main>
        <section className="section section-shaped section-full">
          <div className="shape shape-style-1 bg-gradient-default">
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
          </div>
          <Container className="pt-lg-7">
            {showMessage ? (
              <div className="text-center"><Alert className="px-lg-5" color="danger">{errorMessage}</Alert></div>
            ) : (
              false
            )}
            {loading ? (
              <div className="text-center mb-3">
                <Spinner color="primary" />
              </div>
            ) : (
              false
            )}
            <Row className="justify-content-center">
              <Col lg={5}>
                <Card className="bg-secondary shadow border-0">
                  <CardHeader>
                    <h5 className="text-center text-primary">Đặt lại mật khẩu</h5>
                  </CardHeader>
                  <CardBody className="px-lg-5 py-lg-5">
                    <Form role="form" onSubmit={onHandleResetPassword}>

                      <FormGroup id="code">
                        <InputGroup className="input-group-alternative mb-3">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-lock-circle-open" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            placeholder="Nhập mã code"
                            type="number" min={0} value={code} onChange={(e) => setCode(e.target.value)} />
                        </InputGroup>
                      </FormGroup>

                      <FormGroup id="password">
                        <InputGroup className="input-group-alternative mb-3">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-lock-circle-open" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            required
                            type="password"
                            placeholder="Mật khẩu mới"
                            autoComplete="on"
                            value={newPassword}
                            onChange={(e) => setNewPassword(e.target.value)}
                            invalid={checkPassword}
                          />
                        </InputGroup>
                      </FormGroup>

                      <FormGroup id="confirmPassword">
                        <InputGroup className="input-group-alternative">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-lock-circle-open" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            required
                            type="password"
                            placeholder="Xác nhận mật khẩu"
                            autoComplete="on"
                            value={confirmPassword}
                            onChange={(e) => setConfirmPassword(e.target.value)}
                            invalid={checkPassword}
                          />
                          <FormFeedback>{checkPassword === true ? "Please input match password" : ""}</FormFeedback>
                        </InputGroup>
                      </FormGroup>
                      <div className="text-center">
                        <Button
                          className="mt-4"
                          color="primary"
                          type="submit"
                        >
                          Đặt lại mật khẩu
                        </Button>
                      </div>
                    </Form>
                  </CardBody>
                </Card>
                <Row className="mt-3">
                  <Col className="d-flex justify-content-start align-items-center">
                    <small className="text-light mr-2">
                      Không đổi mật khẩu?
                    </small>
                    <Link
                      to={Routes.ForgotPassword.path}>
                      <small className="text-primary">
                        Quay lại
                      </small>
                    </Link>
                  </Col>
                </Row>
              </Col>
            </Row>
          </Container>
        </section>
      </main>
      {/* <SimpleFooter /> */}
    </>
  );
};
