import React, { useState } from "react";
import { Link, useHistory } from 'react-router-dom';

import { Routes } from "../reoutes";
import { authServices } from "./AuthServices";
import { validateEmail } from "../constans/index";

import {
  Alert,
  Button,
  Card,
  CardBody,
  CardHeader,
  FormGroup,
  Form,
  FormFeedback,
  Input,
  InputGroupAddon,
  InputGroupText,
  InputGroup,
  Container,
  Row,
  Col,
  Spinner
} from "reactstrap";

// core components
// import DemoNavbar from "components/Navbars/DemoNavbar.js";
import SimpleFooter from "components/Footers/SimpleFooter.js";
// import MainBanner from "components/Generals/MainBanner";


export default () => {
  const [loading, setLoading] = useState(false);
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [errorMessage, setErrorMessage] = useState("");
  const [checkUser, setCheckUser] = useState(false);
  const [validEmail, setValidEmail] = useState(false);

  const history = useHistory();

  const onHandleLogin = (event) => {
    event.preventDefault();
    let checkEmail = email.includes("@");
    if (checkEmail) {
      if (validateEmail(email)) {
        setLoading(true);
        setCheckUser(false);
        setValidEmail(false);
        authServices
          .login(email, password)
          .then((rs) => {
            history.push("/profile");
            setCheckUser(false);
            setLoading(false);
          })
          .catch((err) => {
            setCheckUser(true);
            setLoading(false);
            setErrorMessage(err.message);
          });
      } else {
        setCheckUser(false);
        setValidEmail(true);
      }
    } else {
      setLoading(true);
      setCheckUser(false);
      setValidEmail(false);
      authServices
        .login(email, password)
        .then((rs) => {
          history.push("/profile");
          setCheckUser(false);
          setLoading(false);
        })
        .catch((err) => {
          setCheckUser(true);
          setLoading(false);
          setErrorMessage(err.message);
        });
    }
  };

  return (
    <>
      {/* <DemoNavbar /> */}
      <main>
        {/* <MainBanner /> */}
        
        <section className="section section-shaped section-full">
          <div className="shape shape-style-1 bg-gradient-default">
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
          </div>
          <Container className="pt-lg-7">
            {checkUser ? (
              <div className="text-center"><Alert color="danger">{errorMessage}</Alert></div>
            ) : (
              false
            )}
            {loading ? (
              <div className="text-center mb-3">
                <Spinner color="primary" />
              </div>
            ) : (
              false
            )}
            <Row className="justify-content-center">
              <Col lg="5">
                <Card className="bg-secondary shadow border-0">
                <CardHeader>
                    <h5 className="text-center text-primary">Đăng nhập</h5>
                  </CardHeader>
                  <CardBody className="px-lg-5 py-lg-5">
                    <Form role="form" onSubmit={onHandleLogin}>
                      <FormGroup id="email" className="mb-3">
                        <InputGroup className="input-group-alternative">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-email-83" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            required
                            placeholder="Email@gmail.com"
                            type="text"
                            value={email}
                            onChange={(e) => setEmail(e.target.value)}
                            invalid={validEmail}
                          />
                          <FormFeedback className="bg-transparent shadow-0">{validEmail === true ? "Không đúng định dạng email" : ""}</FormFeedback>
                        </InputGroup>
                      </FormGroup>
                      <FormGroup id="password">
                        <InputGroup className="input-group-alternative">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-lock-circle-open" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            required
                            placeholder="Mật khẩu"
                            type="password"
                            autoComplete="off"
                            value={password}
                            onChange={(e) => setPassword(e.target.value)}
                          />
                        </InputGroup>
                      </FormGroup>
                      <div className="text-center">
                        <Button
                          className="my-4"
                          color="primary"
                          type="submit"
                        >
                          Đăng nhập
                        </Button>
                      </div>
                      
                    </Form>
                  </CardBody>
                </Card>
                <Row className="mt-3">
                  <Col xs="6">
                    <Link
                      to={Routes.ForgotPassword.path}
                      className="text-light">
                      <small>Đổi mật khẩu?</small>
                    </Link>
                  </Col>
                  <Col className="text-right" xs="6">
                    <Link
                      to={Routes.Signup.path}
                      className="text-light">
                      <small>Tạo tài khoản</small>
                    </Link>
                  </Col>
                </Row>
              </Col>
            </Row>
          </Container>
        </section>
      </main>
      {/* <SimpleFooter /> */}
    </>
  );
};
