
import React, { useState } from "react";
import { Link, useHistory } from 'react-router-dom';

import { Routes } from "../reoutes";
import { authServices } from "./AuthServices";
import { validateEmail } from "../constans/index";

import {
  Alert,
  Button,
  Card,
  CardBody,
  CardHeader,
  FormGroup,
  Form,
  FormFeedback,
  Input,
  InputGroupAddon,
  InputGroupText,
  InputGroup,
  Container,
  Row,
  Col,
  Spinner
} from "reactstrap";

// core components
import DemoNavbar from "components/Navbars/DemoNavbar.js";
import SimpleFooter from "components/Footers/SimpleFooter.js";

export default () => {
  const [loading, setLoading] = useState(false);
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [confirmPassword, setConfirmPassword] = useState("");
  const [validEmail, setValidEmail] = useState(false);
  const [checkPassword, setCheckPassword] = useState(false);
  const [showMessage, setShowMessage] = useState(false);
  const [errorMessage, setErrorMessage] = useState("");

  const history = useHistory();

  const onHandleSignUp = (event) => {
    event.preventDefault();
    if (validateEmail(email)) {
      setValidEmail(false);
    } else {
      setShowMessage(false);
      setValidEmail(true);
    }
    if (password === confirmPassword) {
      setCheckPassword(false);
    } else {
      setShowMessage(false);
      setCheckPassword(true);
    }

    if (validateEmail(email) && password === confirmPassword) {
      setLoading(true);
      setShowMessage(false);
      authServices
        .signUp(email, password)
        .then((rs) => {
          history.push("/verify-code");
          setShowMessage(false);
          setLoading(false);
        })
        .catch((err) => {
          setShowMessage(true);
          setLoading(false);
          setErrorMessage(err.message);
        });
    }
  };

  return (
    <>
      <DemoNavbar />
      <main>
        <section className="section section-shaped section-full">
          <div className="shape shape-style-1 bg-gradient-default">
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
          </div>
          <Container className="pt-lg-7">
            {showMessage ? (
              <div className="text-center"><Alert className="px-lg-5" color="danger">{errorMessage}</Alert></div>
            ) : (
              false
            )}
            {loading ? (
              <div className="text-center mb-3">
                <Spinner color="primary" />
              </div>
            ) : (
              false
            )}
            <Row className="justify-content-center">
              <Col lg={5}>
                <Card className="bg-secondary shadow border-0">
                  <CardHeader>
                    <h5 className="text-center text-primary">Đăng kí tài khoản</h5>
                  </CardHeader>
                  <CardBody className="px-lg-5 py-lg-5">
                    <Form role="form" onSubmit={onHandleSignUp}>

                      <FormGroup id="email">
                        <InputGroup className="input-group-alternative mb-3">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-email-83" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            required
                            placeholder="Email@gmail.com"
                            type="email"
                            value={email}
                            onChange={(e) => setEmail(e.target.value)}
                            invalid={validEmail} />
                          <FormFeedback className="bg-transparent shadow-0">{validEmail === true ? "Không đúng định dạng email" : ""}</FormFeedback>
                        </InputGroup>
                      </FormGroup>

                      <FormGroup id="password">
                        <InputGroup className="input-group-alternative mb-3">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-lock-circle-open" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            required
                            placeholder="Mật khẩu"
                            type="password"
                            autoComplete="off"
                            value={password}
                            onChange={(e) => setPassword(e.target.value)} 
                            invalid={checkPassword}
                          />
                          <FormFeedback>{checkPassword === true ? "Mật khẩu không trùng nhau" : ""}</FormFeedback>
                        </InputGroup>

                      </FormGroup>

                      <FormGroup id="confirmPassword">
                        <InputGroup className="input-group-alternative">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-lock-circle-open" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            required
                            placeholder="Xác nhận mật khẩu"
                            type="password"
                            autoComplete="off"
                            value={confirmPassword}
                            onChange={(e) => setConfirmPassword(e.target.value)}
                            invalid={checkPassword}
                          />
                          <FormFeedback>{checkPassword === true ? "Mật khẩu không trùng nhau" : ""}</FormFeedback>
                        </InputGroup>
                      </FormGroup>
                      <div className="text-center">
                        <Button
                          className="mt-4"
                          color="primary"
                          type="submit"
                        >
                          Tạo tài khoản
                        </Button>
                      </div>
                    </Form>
                  </CardBody>
                </Card>
                <Row className="mt-3">
                  <Col className="d-flex justify-content-start align-items-center">
                    <small className="text-light mr-2">
                      Bạn đã có tài khoản?
                    </small>
                    <Link
                      to={Routes.Signin.path}>
                      <small className="text-primary">
                        Đăng nhập
                      </small>
                    </Link>
                  </Col>
                </Row>
              </Col>
            </Row>
          </Container>
        </section>
      </main>
      <SimpleFooter />
    </>
  );
};
