
import React, { useState } from "react";
import { Link, useHistory } from 'react-router-dom';

import { Routes } from "../reoutes";
import { authServices } from "./AuthServices";

import {
  Alert,
  Button,
  Card,
  CardBody,
  FormGroup,
  Form,
  Input,
  InputGroupAddon,
  InputGroupText,
  InputGroup,
  Container,
  Row,
  Col,
  Spinner
} from "reactstrap";

// core components
import DemoNavbar from "components/Navbars/DemoNavbar.js";
import SimpleFooter from "components/Footers/SimpleFooter.js";

export default () => {
  const [loading, setLoading] = useState(false);
  const [code, setCode] = useState("");
  const [showMessage, setShowMessage] = useState(false);
  const [errorMessage, setErrorMessage] = useState("");

  const history = useHistory();

  const onHandleVerifyCode = (event) => {
    event.preventDefault();
    setLoading(true);
    setShowMessage(false);
    authServices
      .verifyCode(code)
      .then((rs) => {
        history.push(Routes.Signin.path);
        setShowMessage(false);
        setLoading(false);
      })
      .catch((err) => {
        setShowMessage(true);
        setLoading(false);
        setErrorMessage(err.message);
      });
  };

  return (
    <>
      <DemoNavbar />
      <main>
        <section className="section section-shaped section-full">
          <div className="shape shape-style-1 bg-gradient-default">
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
            <span />
          </div>
          <Container className="pt-lg-7">
            {showMessage ? (
              <div className="text-center"><Alert className="px-lg-5" color="danger">{errorMessage}</Alert></div>
            ) : (
              false
            )}
            {loading ? (
              <div className="text-center mb-3">
                <Spinner color="primary" />
              </div>
            ) : (
              false
            )}
            <Row className="justify-content-center">
              <Col lg={5}>
                <Card className="bg-secondary shadow border-0">
                  <CardBody className="px-lg-5 py-lg-5">
                    <Form role="form" onSubmit={onHandleVerifyCode}>

                      <FormGroup id="code">
                        <InputGroup className="input-group-alternative mb-3">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="ni ni-lock-circle-open" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            autoFocus
                            required
                            type="number"
                            placeholder="Nhập mã code"
                            min={0}
                            value={code}
                            onChange={(e) => setCode(e.target.value)} />
                        </InputGroup>
                      </FormGroup>
                      <div className="text-center">
                        <Button
                          className="mt-4"
                          color="primary"
                          type="submit"
                        >
                          Xác nhận
                        </Button>
                      </div>
                    </Form>
                  </CardBody>
                </Card>
                <Row className="mt-3">
                  <Col className="d-flex justify-content-start align-items-center">
                    <Link
                      to={Routes.Signup.path}>
                      <small className="text-primary">
                        Quay lại đăng kí
                      </small>
                    </Link>
                  </Col>
                </Row>
              </Col>
            </Row>
          </Container>
        </section>
      </main>
      {/* <SimpleFooter /> */}
    </>
  );
};
