import React, { useState } from "react";
import { useHistory } from "react-router-dom";
import { useDispatch } from "react-redux";
import {
  Table, Card, CardHeader, Row, Col, Button,
  UncontrolledDropdown, DropdownToggle, DropdownMenu, DropdownItem, Pagination, PaginationItem, PaginationLink,
  Modal, ModalHeader, ModalBody, ModalFooter, Form, FormGroup, Label, InputGroup, InputGroupAddon, InputGroupText, Input
} from "reactstrap";
import QRCode from 'qrcode.react';
import { profileFormatDateTime } from "constans";

export const ProfileTable = (props) => {
  const history = useHistory();
  const dispatch = useDispatch();

  const onHandleClickAdd = () => {
    history.push("/profile/add");
  };

  const onHandleClickEdit = (profileId) => {
    let detailProfile = props.listProfile.filter(item => item.id === profileId);
    history.push({
      pathname: "/profile/add",
      state: { profileId, detailProfile }  
    });
  } 

  const onHandleClickDelete = (profileId) => {
    return props.listProfile.filter(item => item.id !== profileId);
    // dispatch(props.onDeleteProfile(profileId));
  }


  const items = [];
  const totalItem = props.total;
  let pageSize = totalItem / props.limit;

  const getPageItem = () => {
    let number = 1;
    if(pageSize > 1){
      number = Math.ceil(pageSize);
    }else {
      number = 1;
    }
    return number;
  }

  for(let number=1; number <= getPageItem(); number++){
    const isItemActive = props.currentPage === number;
    const handlePaginationChange = () => {
      dispatch(props.onLoadListProfile( { currentPage: number, limit: props.limit } ));
      dispatch(props.onLoadPreviousPage(number));
    };
    items.push(
      <PaginationItem active={isItemActive} key={number} onClick={handlePaginationChange}>
        <PaginationLink>{number}</PaginationLink>
      </PaginationItem>
    );
  }

  const onPrevItem = () => {
    const prevActiveItem = props.currentPage === 1 ? props.currentPage : props.currentPage - 1;
    dispatch(props.onLoadListProfile({ currentPage: props.previosPage, limit: props.limit }));
    dispatch(props.onLoadPreviousPage(prevActiveItem));
  };

  const onNextItem = () => {
    const nextActiveItem = props.currentPage === Math.ceil(pageSize) ? props.currentPage : props.currentPage + 1;
    dispatch(props.onLoadListProfile({ currentPage: props.nextPage, limit: props.limit }));
    dispatch(props.onLoadNextPage(nextActiveItem));
  };

  let count = 0;
  const TableRow = (props) => {
    const { id, address, logo, name, phone_number, profile_product, created_at, code } = props;
    count++;
    
    const productName = profile_product ? profile_product.map(item => item.name) : [];
    let listProductName = [];
    for(let i=0; i<productName.length; i++){
      listProductName += productName[i] + '<br />';
    }

    return (
      <tr>
        <th scope="row">{count}</th>
        <td>{name}</td>
        <td>{phone_number}</td>
        <td>{address}</td>
        <td dangerouslySetInnerHTML={{__html: listProductName}}></td>
        <td>{created_at ? profileFormatDateTime(created_at) : ""}</td>
        <td>
          <QRCode
            size={120}
            includeMargin
            value={`http://trace.aqbits.net/${code}`}
            imageSettings={{
              width: 60,
              height: 40,
              src: window.location.origin + logo,
              excavate: true,
            }}
          />
        </td>
        <td key={id}>
          <UncontrolledDropdown nav>
            <DropdownToggle nav>
              <i className="fa fa-ellipsis-h" />
            </DropdownToggle>
            <DropdownMenu>
              <DropdownItem onClick={() => onHandleClickEdit(id)} >
                <i className="fa fa-pencil mr-3" />{"Sửa"}
              </DropdownItem>
              <DropdownItem className="text-danger" onClick={() => onHandleClickDelete(id)}>
                <i className="fa fa-trash mr-3" />{"Xóa"}
              </DropdownItem>
            </DropdownMenu>
          </UncontrolledDropdown>
        </td>
      </tr>
    );
  };

  return (
    props.listProfile && props.listProfile.length > 0 ?
      <Card className="mx-5">
        <CardHeader>
          <Row className="align-items-center">
            <Col>
              <h5>{"Thông tin doanh nghiệp"}</h5>
            </Col>
            <Col className="text-right">
              <Button className="btn-1 ml-1" color="success" size="sm" type="button" onClick={() => onHandleClickAdd()}>{"Tạo mới doanh nghiệp"}</Button>
            </Col>
          </Row>
        </CardHeader>
        <Table striped responsive>
          <thead>
            <tr >
              <th>{"STT"}</th>
              <th>{"Tên doanh nghiệp"}</th>
              <th>{"Số điện thoại"}</th>
              <th>{"Địa chỉ"}</th>
              <th>{"Tên sản phẩm"}</th>
              <th>{"Ngày tạo"}</th>
              <th>{"QR code"}</th>
              <th></th>
            </tr>
          </thead>
          <tbody>
            {props.listProfile ? props.listProfile.map(profile => <TableRow key={`page-visit-${profile.id}`} {...profile} />) : []}
          </tbody>
        </Table>
        <Row  className="mx-3 my-2">
          <Col>
            <nav>
              <Pagination aria-label="Page navigation example">
                <PaginationItem disabled={props.currentPage === 1}>
                  <PaginationLink first href="#" />
                </PaginationItem>
                <PaginationItem disabled={props.currentPage === 1} onClick={onPrevItem}>
                  <PaginationLink previous href="#" />
                </PaginationItem>
                {items}
                <PaginationItem disabled={props.currentPage === Math.ceil(pageSize)} onClick={onNextItem}>
                  <PaginationLink next href="#" />
                </PaginationItem>
                <PaginationItem disabled={props.currentPage === Math.ceil(pageSize)}>
                  <PaginationLink last href="#" />
                </PaginationItem>
              </Pagination>
            </nav>
          </Col>
          <Col className="text-right">
            <h6 className="font-weight-bold">
              {('Hiển thị ' + props.listProfile.length + "/" + totalItem)}
            </h6>
          </Col>
        </Row>
      </Card> 
      : <div></div>
  );
}

export const ProductTable = (props) => {
  const history = useHistory();
  // const dispatch = useDispatch();


  const onHandleClickEdit = (productId) => {
    let detailProduct = props.listProduct.filter(item => item.product_id === productId);
    history.push({
      pathname: "/profile/add-product",
      state: { productId, detailProduct }  
    });
  } 

  const onHandleClickDelete = (profileId) => {
    // dispatch(props.onDeleteProfile(profileId));
  }

  const onHandleClickAdd = () => {
    history.push({
      pathname: "/profile/add-product",
      // state: { profileId }
    });
  }

  const items = [];
  const totalItem = props.listProduct ? props.listProduct.length : 1;
  let pageSize = totalItem / 10;

  const getPageItem = () => {
    let number = 1;
    if(pageSize > 1){
      number = Math.ceil(pageSize);
    }else {
      number = 1;
    }
    return number;
  }

  for(let number=1; number <= getPageItem(); number++){
    // const isItemActive = props.currentPage === number;
    const handlePaginationChange = () => {
      // dispatch(props.onLoadListProfile( { currentPage: number, limit: props.limit } ));
      // dispatch(props.onLoadPreviousPage(number));
    };
    items.push(
      <PaginationItem key={number} onClick={handlePaginationChange}>
        <PaginationLink>{number}</PaginationLink>
      </PaginationItem>
    );
  }

  let count = 0;
  const TableRow = (props) => {
    const { product_id, name, trace_code, cost, origin, image, growing_conditions, description, created_at, qr_code } = props;
    count++;

    return (
      <tr>
        <th scope="row">{count}</th>
        <td>{name}</td>
        <td>{trace_code}</td>
        <td>{cost}</td>
        <td>{origin}</td>
        <td>{description}</td>
        <td>{growing_conditions}</td>
        <td>
          <QRCode
            size={120}
            includeMargin
            value={`http://trace.aqbits.net/trace-code/${qr_code}`}
            imageSettings={{
              width: 60,
              height: 40,
              src: window.location.origin + image,
              excavate: true,
            }}
          />
          {/* <img src={window.location.origin + qr_code} alt="qr-code" width={50} height={50} /> */}
        </td>
        <td>{created_at ? profileFormatDateTime(created_at) : ""}</td>
        <td key={product_id}>
          <UncontrolledDropdown nav>
            <DropdownToggle nav>
              <i className="fa fa-ellipsis-h" />
            </DropdownToggle>
            <DropdownMenu>
              <DropdownItem onClick={() => onHandleClickEdit(product_id)} >
                <i className="fa fa-pencil mr-3" />{"Sửa"}
              </DropdownItem>
              <DropdownItem className="text-danger" onClick={() => onHandleClickDelete(product_id)}>
                <i className="fa fa-trash mr-3" />{"Xóa"}
              </DropdownItem>
            </DropdownMenu>
          </UncontrolledDropdown>
        </td>
      </tr>
    );
  };

  return (
    props.listProduct && props.listProduct.length > 0 ?
      <Card>
        <CardHeader>
          <Row className="align-items-center">
            <Col>
              <h5 className="mb-3">{"Danh sách sản phẩm"}</h5>
            </Col>
            <Col className="text-right">
              <Button className="btn-1 ml-1" color="success" size="sm" type="button" onClick={() => onHandleClickAdd()}>{"Thêm mới sản phẩm"}</Button>
            </Col>
          </Row>
        </CardHeader>
        <Table striped responsive>
          <thead>
            <tr >
              <th>{"STT"}</th>
              <th>{"Tên sản phẩm"}</th>
              <th>{"Mã sản phẩm"}</th>
              <th>{"Giá sản phẩm"}</th>
              <th>{"Xuất xứ"}</th>
              <th>{"Mô tả"}</th>
              <th>{"Điều kiện nuôi trồng"}</th>
              <th>{"QR code"}</th>
              <th>{"Ngày tạo"}</th>
              <th></th>
            </tr>
          </thead>
          <tbody>
            {props.listProduct ? props.listProduct.map(product => <TableRow key={`page-visit-${product.product_id}`} {...product} />) : []}
          </tbody>
        </Table>
        <Row  className="mx-3 my-2">
          <Col>
            <nav>
              <Pagination aria-label="Page navigation example">
                <PaginationItem>
                  <PaginationLink first href="#" />
                </PaginationItem>
                <PaginationItem>
                  <PaginationLink previous href="#" />
                </PaginationItem>
                {items}
                <PaginationItem>
                  <PaginationLink next href="#" />
                </PaginationItem>
                <PaginationItem>
                  <PaginationLink last href="#" />
                </PaginationItem>
              </Pagination>
            </nav>
          </Col>
          <Col className="text-right">
            <h6 className="font-weight-bold">
              {('Hiển thị ' + props.listProduct.length + "/" + totalItem)}
            </h6>
          </Col>
        </Row>
      </Card> 
      : <div></div>
  );
}

export const ProductDiaryTable = (props) => {
  const [modal, setModal] = useState(false);
  const [company, setCompany] = useState("");
  const [description, setDescription] = useState("");
  const [createDate, setCreateDate] = useState("");

  const history = useHistory();
  // const dispatch = useDispatch();
  
  const toggleModal = (id) => {
    let detailProductDiary = props.listProductDiary.filter(item => item.id === id);
    if(detailProductDiary.length > 0){
      setCompany(detailProductDiary[0].company);
      setDescription(detailProductDiary[0].description);
      setCreateDate(profileFormatDateTime(detailProductDiary[0].date))
    }else {
      setCompany("");
      setDescription("");
    }
    setModal(!modal);
  };

  const onHandleClickAdd = () => {
    
  } 

  const onHandleClickDelete = (id) => {
    // dispatch(props.onDeleteProfile(profileId));
  }

  const items = [];
  const totalItem = props.listProductDiary ? props.listProductDiary.length : 1;
  let pageSize = totalItem / 10;

  const getPageItem = () => {
    let number = 1;
    if(pageSize > 1){
      number = Math.ceil(pageSize);
    }else {
      number = 1;
    }
    return number;
  }

  for(let number=1; number <= getPageItem(); number++){
    // const isItemActive = props.currentPage === number;
    const handlePaginationChange = () => {
      // dispatch(props.onLoadListProfile( { currentPage: number, limit: props.limit } ));
      // dispatch(props.onLoadPreviousPage(number));
    };
    items.push(
      <PaginationItem key={number} onClick={handlePaginationChange}>
        <PaginationLink>{number}</PaginationLink>
      </PaginationItem>
    );
  }

  let count = 0;
  const TableRow = (props) => {
    const { id, company, description, date } = props;
    count++;

    return (
      <tr>
        <th scope="row">{count}</th>
        <td>{company}</td>
        <td>{description}</td>
        <td>{date ? profileFormatDateTime(date) : ""}</td>
        <td key={id}>
          <UncontrolledDropdown nav>
            <DropdownToggle nav>
              <i className="fa fa-ellipsis-h" />
            </DropdownToggle>
            <DropdownMenu>
              <DropdownItem onClick={() => toggleModal(id)} >
                <i className="fa fa-pencil mr-3" />{"Sửa"}
              </DropdownItem>
              <DropdownItem className="text-danger" onClick={() => onHandleClickDelete(id)}>
                <i className="fa fa-trash mr-3" />{"Xóa"}
              </DropdownItem>
            </DropdownMenu>
          </UncontrolledDropdown>
        </td>
      </tr>
    );
  };

  return (
    props.listProductDiary && props.listProductDiary.length > 0 ?
      <Card>
        <CardHeader>
          <Row className="align-items-center">
            <Col>
              <h5>{"Nhật kí sản phẩm"}</h5>
            </Col>
            <Col className="text-right">
              <div>
                <Button className="btn-1 ml-1" color="success" size="sm" type="button" onClick={() => toggleModal()}>{"Tạo mới nhật kí"}</Button>
                <Modal isOpen={modal} toggle={() => toggleModal()}>
                  <ModalHeader toggle={() => toggleModal()}>{company ? "Sửa nhật kí" : "Thêm nhật kí"}</ModalHeader>
                  <ModalBody>
                    <Form>
                      <FormGroup>
                        <Label for="company-name">Tên công ty</Label>
                        <InputGroup className="mb-4">
                          <InputGroupAddon addonType="prepend">
                            <InputGroupText>
                              <i className="fa fa-building" />
                            </InputGroupText>
                          </InputGroupAddon>
                          <Input
                            placeholder="Tên công ty"
                            type="text"
                            value={company}
                            onChange={(e) => setCompany(e.target.value)}
                          />
                        </InputGroup>
                      </FormGroup>
                      <FormGroup>
                        <Label for="diary-description">Mô tả</Label>
                        <InputGroup className="mb-4">
                          <Input
                            placeholder="Mô tả"
                            type="textarea"
                            value={description}
                            onChange={(e) => setDescription(e.target.value)}
                          />
                        </InputGroup>
                      </FormGroup>
                      {company ? <FormGroup>
                        <Label for="diary-date">Thời gian tạo</Label>
                        <InputGroup className="mb-4">
                          <Input
                            placeholder="Thời gian tạo"
                            type="text"
                            value={createDate}
                            disabled
                          />
                        </InputGroup>
                      </FormGroup> : <div></div>}
                    </Form>
                  </ModalBody>
                  <ModalFooter>
                    <Button color="primary" size="sm" onClick={onHandleClickAdd}>{company ? "Sửa" : "Thêm mới"}</Button>
                  </ModalFooter>
                </Modal>
              </div>
            </Col>
          </Row>
        </CardHeader>
        <Table striped responsive>
          <thead>
            <tr >
              <th>{"STT"}</th>
              <th>{"Tên công ty"}</th>
              <th>{"Mô tả"}</th>
              <th>{"Ngày tháng"}</th>
              <th></th>
            </tr>
          </thead>
          <tbody>
            {props.listProductDiary ? props.listProductDiary.map(productDiary => <TableRow key={`page-visit-${productDiary.id}`} {...productDiary} />) : []}
          </tbody>
        </Table>
        <Row  className="mx-3 my-2">
          <Col>
            <nav>
              <Pagination aria-label="Page navigation example">
                <PaginationItem>
                  <PaginationLink first href="#" />
                </PaginationItem>
                <PaginationItem>
                  <PaginationLink previous href="#" />
                </PaginationItem>
                {items}
                <PaginationItem>
                  <PaginationLink next href="#" />
                </PaginationItem>
                <PaginationItem>
                  <PaginationLink last href="#" />
                </PaginationItem>
              </Pagination>
            </nav>
          </Col>
          <Col className="text-right">
            <h6 className="font-weight-bold">
              {('Hiển thị ' + props.listProductDiary.length + "/" + totalItem)}
            </h6>
          </Col>
        </Row>
      </Card> 
      : <div></div>
  );
}